@@ -1,24 +1,31 @@
 """
 Created on 4 Mar 2021
 
-:author: semuadmin
-:copyright: SEMU Consulting © 2020
+:author: semuadmin (Steve Smith)
+:copyright: semuadmin © 2020
 :license: BSD 3-Clause
 """
+
 # pylint: disable=wrong-import-position, invalid-name
 
 from pynmeagps._version import __version__
 from pynmeagps.exceptions import (
     NMEAMessageError,
     NMEAParseError,
-    NMEATypeError,
     NMEAStreamError,
+    NMEATypeError,
 )
+from pynmeagps.nmeahelpers import *
 from pynmeagps.nmeamessage import NMEAMessage
 from pynmeagps.nmeareader import NMEAReader
-from pynmeagps.socket_stream import SocketStream
 from pynmeagps.nmeatypes_core import *
+from pynmeagps.nmeatypes_decodes import *
 from pynmeagps.nmeatypes_get import *
-from pynmeagps.nmeahelpers import *
+from pynmeagps.nmeatypes_get_prop import *
+from pynmeagps.nmeatypes_poll import *
+from pynmeagps.nmeatypes_poll_prop import *
+from pynmeagps.nmeatypes_set import *
+from pynmeagps.nmeatypes_set_prop import *
+from pynmeagps.socketwrapper import SocketWrapper
 
 version = __version__
